@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Pg;
 use Carp;
 
-our $VERSION = '1.4';
+our $VERSION = '1.5';
 our $Debug = 0;
 has pg => sub { +{} };
 
@@ -336,7 +336,7 @@ sub _build_order_by_clause {
 sub _quote_identifier {
     my ($self, $identifier) = @_;
     return join '.', map { 
-        qq{$_}
+        $self->pg->db->dbh->quote_identifier($_) 
     } split /\./, $identifier;
 }
 
@@ -380,6 +380,13 @@ Mojolicious::Plugin::QuickPg - Mojolicious Plugin that provided quick access met
   
   my $id = $c->qinsert('models', { name => 'Moscow',
                                    foto => 'https://www.flickr.com/search/?text=Moscow' } );
+  # or you can do like this
+  
+  my $params = $c->req->json;
+  
+  # Do not forget to validate $params before it:
+  
+  my $id = $c->insert('models', $params);
   
   # quick update
   # returns numbers of updated rows
